Enum FailedToBufferBody
#[non_exhaustive]pub enum FailedToBufferBody {
LengthLimitError(LengthLimitError),
UnknownBodyError(UnknownBodyError),
}Expand description
Rejection type for extractors that buffer the request body. Used if the request body cannot be buffered due to an error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LengthLimitError(LengthLimitError)
UnknownBodyError(UnknownBodyError)
Implementations
impl FailedToBufferBody
impl FailedToBufferBody
pub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the status code used for this rejection.